<?php

/**
 * discussions actions.
 *
 * @package    sf_sandbox
 * @subpackage discussions
 * @author     Your name here
 * @version    SVN: $Id: actions.class.php 12474 2008-10-31 10:41:27Z fabien $
 */
class discussionsActions extends sfActions
{
  public function executeIndex(sfWebRequest $request)
  {
    $this->projectId = $request->getParameter('projectId');

    $c = new Criteria();
    $c->add(DiscussionsPeer::PROJECTS_ID,$this->projectId);
    $c->addAscendingOrderByColumn(DiscussionsPeer::DISCUSSIONS_STATUS_ID);
    $c->addAscendingOrderByColumn(DiscussionsPeer::NAME);
    
    $pager = new sfPropelPager('Discussions', sfConfig::get('app_rows_per_page_group'));
    $pager->setPeerMethod('doSelectJoinAll');
    $pager->setPeerCountMethod('doCountJoinAll');
    $pager->setCriteria($c);
    $pager->setPage($this->getRequestParameter('page', 1));
    $pager->init();
    $this->pager = $pager;
    
    $this->discussions_list = DiscussionsPeer::doSelectJoinAll($c);
    
    $response = $this->getResponse();
    $response->setTitle(sfConfig::get('app_app_short_name') . ' | ' . I18NText::__('Discussions'));
  }

  public function executeNew(sfWebRequest $request)
  {
    $this->form = new DiscussionsForm(null, array('projectId' => $request->getParameter('projectId'),'userId'=>$this->getUser()->getAttribute('userId')));
    
    $this->form->setDefault('projects_id', $request->getParameter('projectId'));
    $this->form->setDefault('users_id', $this->getUser()->getAttribute('userId'));
  }

  public function executeCreate(sfWebRequest $request)
  {
    $this->forward404Unless($request->isMethod('post'));

    $this->form = new DiscussionsForm(null, array('projectId' => $request->getParameter('projectId'),'userId'=>$this->getUser()->getAttribute('userId')));

    $this->processForm($request, $this->form);

    $this->setTemplate('new');
  }

  public function executeEdit(sfWebRequest $request)
  {
    $this->forward404Unless($discussions = DiscussionsPeer::retrieveByPk($request->getParameter('id')), sprintf('Object discussions does not exist (%s).', $request->getParameter('id')));
    $this->form = new DiscussionsForm($discussions, array('projectId' => $request->getParameter('projectId'),'userId'=>$this->getUser()->getAttribute('userId')));
  }

  public function executeUpdate(sfWebRequest $request)
  {
    $this->forward404Unless($request->isMethod('post') || $request->isMethod('put'));
    $this->forward404Unless($discussions = DiscussionsPeer::retrieveByPk($request->getParameter('id')), sprintf('Object discussions does not exist (%s).', $request->getParameter('id')));
    $this->form = new DiscussionsForm($discussions, array('projectId' => $request->getParameter('projectId'),'userId'=>$this->getUser()->getAttribute('userId')));

    $this->processForm($request, $this->form);

    $this->setTemplate('edit');
  }

  public function executeDelete(sfWebRequest $request)
  {
    $request->checkCSRFProtection();

    $this->forward404Unless($discussions = DiscussionsPeer::retrieveByPk($request->getParameter('id')), sprintf('Object discussions does not exist (%s).', $request->getParameter('id')));
    
    $projectId = $discussions->getProjectsId();
    
    AttachmentsPeer::deleteAttachments('discussions', $discussions->getId());
    
    $discussions->delete();

    $this->redirect('discussions/index?projectId=' . $projectId);
  }

  protected function processForm(sfWebRequest $request, sfForm $form)
  {
    //insert attachments
    $attachments_files = array();
    $files = $request->getFiles();

    foreach($files['attachments'] as $key=>$file)
    {
      if(strlen($file['name'])>0)
      {
        $filename = rand(111111,999999)  . '-' . $file['name'];
        move_uploaded_file($file['tmp_name'], sfConfig::get('sf_upload_dir') . '/attachments/'  . $filename);
        $attachments_files[] = $filename;
      }
      else
      {
        $attachments_files[] = '';
      }
    }
    
    $sendNofification = false;
    
    $form->bind($request->getParameter($form->getName()), $request->getFiles($form->getName()));
    if ($form->isValid())
    {
      if($form->getObject()->isNew())
      {
        $sendNofification = true;
      }
      
      $form->setFieldValue('assigned_to',implode(',',$form['assigned_to']->getValue()));
    
      $discussions = $form->save();
      
      AttachmentsPeer::insertAttachments($request->getParameter('attachments_id'), $request->getParameter('attachments_info'),$attachments_files,$discussions->getId(),'discussions');


      $projects = ProjectsPeer::retrieveByPk($discussions->getProjectsId());
      
       //send notification
      if($sendNofification==true && strlen($projects->getTeam())>0)
      {
        $sendTo = array();
        $sendFrom = array();

        $c = new Criteria();
        $c->add(UsersPeer::ACTIVE,1);
        $c->add(UsersPeer::ID,explode(',',$discussions->getAssignedTo()), Criteria::IN);
        $users_list = UsersPeer::doSelect($c);

        foreach($users_list as $users)
        {
          $sendTo[$users->getEmail()] = $users->getName();
        }
        
        if(isset($sendTo[$this->getUser()->getAttribute('userEmail')]))
        {
          unset($sendTo[$this->getUser()->getAttribute('userEmail')]);
        }

        $c = new Criteria();
        $c->add(UsersPeer::ID,$discussions->getUsersId());
        $user = UsersPeer::doSelectOne($c);

        $sendFrom[$user->getEmail()] = $user->getName();

        require_once sfConfig::get('sf_lib_dir').'/vendor/swift_init.php';

        $subject = I18NText::__('New Discussion') . ': ' . $discussions->getName() . ' [' . $discussions->getProjects()->getName()  . ']';
        $body = $this->getComponent('discussions','emailNewDiscussion', array('discussionId'=>$discussions->getId()));

        UsersPeer::sendEmail($sendTo,$subject,$body, $sendFrom,$this->getUser());
      }
      
      if($request->getParameter('redirectTo')=='discussionsComments')
      {
        $this->redirect('discussionsComments/index?projectId=' . $discussions->getProjectsId() . '&discussionId=' . $discussions->getId());
      }
      else
      {      
        $this->redirect('discussions/index?projectId=' . $discussions->getProjectsId());
      }
      
    }
  }
}
