<?php

/**
 * projects actions.
 *
 * @package    sf_sandbox
 * @subpackage projects
 * @author     Your name here
 * @version    SVN: $Id: actions.class.php 12474 2008-10-31 10:41:27Z fabien $
 */
class projectsActions extends sfActions
{
  public function executeIndex(sfWebRequest $request)
  {
    UsersPeer::clearUsersFilters($this->getUser());
  
    /**
     *set default project filter by status
     */
    if(!$this->getUser()->hasAttribute('filterProjectsByStatusId'))
    {
      $this->getUser()->setAttribute('filterProjectsByStatusId', ProjectsStatusPeer::getDafaultStatusId());
    }
     
     
    /**
     *save projects filters in session
     */
    if($request->hasParameter('filterProjectsByStatusId'))
    {
      $this->getUser()->setAttribute('filterProjectsByStatusId', $request->getParameter('filterProjectsByStatusId'));
    }

    if($request->hasParameter('filterProjectsByTypeId'))
    {
      $this->getUser()->setAttribute('filterProjectsByTypeId', $request->getParameter('filterProjectsByTypeId'));
    }
    
    if($request->hasParameter('filterProjectsByUserId'))
    {
      $this->getUser()->setAttribute('filterProjectsByUserId', $request->getParameter('filterProjectsByUserId'));
    }
    
    
    
    if(!$this->getUser()->hasCredential('allow_manage_tasks'))
    {
      $this->getUser()->getAttributeHolder()->remove('filterProjectsByStatusId');
      $this->getUser()->getAttributeHolder()->remove('filterProjectsByTypeId');    
      $this->getUser()->getAttributeHolder()->remove('filterProjectsByUserId');
    }
    
    /**
     *build criteria using filters
     */
    $c = new Criteria();
    
    if($this->getUser()->getAttribute('filterProjectsByStatusId')>0)
    {
      $c->add(ProjectsPeer::PROJECTS_STATUS_ID, $this->getUser()->getAttribute('filterProjectsByStatusId'));
    }

    if($this->getUser()->getAttribute('filterProjectsByTypeId')>0)
    {
      $c->add(ProjectsPeer::PROJECTS_TYPES_ID, $this->getUser()->getAttribute('filterProjectsByTypeId'));
    }
    
    if($this->getUser()->getAttribute('filterProjectsByUserId')>0)
    {
      $c->add('',"FIND_IN_SET(" . $this->getUser()->getAttribute('filterProjectsByUserId') . "," . ProjectsPeer::TEAM . ")", Criteria::CUSTOM);
    }
    
    if(!$this->getUser()->hasCredential('allow_view_all'))
    {
      $c->add('','(' . ProjectsPeer::CREATED_BY . '=' . $this->getUser()->getAttribute('userId') . " or FIND_IN_SET(" . $this->getUser()->getAttribute('userId') . "," . ProjectsPeer::TEAM . "))", Criteria::CUSTOM);
    }
    
    
    
    
    $c->addAscendingOrderByColumn(ProjectsPeer::PROJECTS_STATUS_ID);
    $c->addAscendingOrderByColumn(ProjectsPeer::NAME);
    
    
    $pager = new sfPropelPager('Projects', sfConfig::get('app_rows_per_page_group'));
    $pager->setPeerMethod('doSelectJoinAll');
    $pager->setPeerCountMethod('doCountJoinAll');
    $pager->setCriteria($c);
    $pager->setPage($this->getRequestParameter('page', 1));
    $pager->init();
    $this->pager = $pager;
    
    $this->projects_list = ProjectsPeer::doSelectJoinAll($c);
    
    $this->countProjectsTypes = BaseProjectsTypesPeer::doCount(new Criteria());
    $this->countProjectsStatus = BaseProjectsStatusPeer::doCount(new Criteria());
    
    $response = $this->getResponse();
    $response->setTitle(sfConfig::get('app_app_short_name') . ' | ' . I18NText::__('Projects'));
  }

  public function executeNew(sfWebRequest $request)
  {
    $this->form = new ProjectsForm();
    $this->form->setDefault('created_by', $this->getUser()->getAttribute('userId'));
  }

  public function executeCreate(sfWebRequest $request)
  {
    $this->forward404Unless($request->isMethod('post'));

    $this->form = new ProjectsForm();

    $this->processForm($request, $this->form);

    $this->setTemplate('new');
  }

  public function executeEdit(sfWebRequest $request)
  {
    $this->forward404Unless($projects = ProjectsPeer::retrieveByPk($request->getParameter('id')), sprintf('Object projects does not exist (%s).', $request->getParameter('id')));
    $this->form = new ProjectsForm($projects);
  }

  public function executeUpdate(sfWebRequest $request)
  {
    $this->forward404Unless($request->isMethod('post') || $request->isMethod('put'));
    $this->forward404Unless($projects = ProjectsPeer::retrieveByPk($request->getParameter('id')), sprintf('Object projects does not exist (%s).', $request->getParameter('id')));
    $this->form = new ProjectsForm($projects);

    $this->processForm($request, $this->form);

    $this->setTemplate('edit');
  }

  public function executeDelete(sfWebRequest $request)
  {
    $request->checkCSRFProtection();

    $this->forward404Unless($projects = ProjectsPeer::retrieveByPk($request->getParameter('id')), sprintf('Object projects does not exist (%s).', $request->getParameter('id')));

    ExtraFields::deleteByBindId($projects->getId(),'projects');
    AttachmentsPeer::deleteAttachments('projects', $projects->getId());
    
    foreach(Tasks::getTasksListByProjectID($projects->getId()) as $v)
    {
      ExtraFields::deleteByBindId($v->getId(),'tasks');
      AttachmentsPeer::deleteAttachments('tasks', $v->getId());
    }
    
    foreach(Tickets::getTicketsListByProjectID($projects->getId()) as $v)
    {
      ExtraFields::deleteByBindId($v->getId(),'tickets');
      AttachmentsPeer::deleteAttachments('tickets', $v->getId());
    }
    
    foreach(Discussions::getDiscussionsListByProjectID($projects->getId()) as $v)
    {      
      AttachmentsPeer::deleteAttachments('discussions', $v->getId());
    }
    
    $projects->delete();

    $this->redirect('projects/index');
  }

  protected function processForm(sfWebRequest $request, sfForm $form)
  {
    $sendNofification = false;
    
    //insert attachments
    $attachments_files = array();
    $files = $request->getFiles();
    
    foreach($files['attachments'] as $key=>$file)
    {
      if(strlen($file['name'])>0)
      {
        $filename = rand(111111,999999)  . '-' . $file['name'];
        move_uploaded_file($file['tmp_name'], sfConfig::get('sf_upload_dir') . '/attachments/'  . $filename);
        $attachments_files[] = $filename;
      }
      else
      {
        $attachments_files[] = '';
      }
    }

    $form->bind($request->getParameter($form->getName()), $request->getFiles($form->getName()));
    if ($form->isValid())
    {
      if($form->getObject()->isNew())
      {
        $sendNofification = true;
      }
    
      if($request->hasParameter('users'))
      {
        $form->setFieldValue('team',implode(',',$request->getParameter('users')));
      }
    
      $projects = $form->save();
      
      AttachmentsPeer::insertAttachments($request->getParameter('attachments_id'), $request->getParameter('attachments_info'),$attachments_files,$projects->getId(),'projects');

      //insert extra fields values
      if($request->hasParameter('extra_fields'))
      {
        ExtraFieldsListPeer::insertFieldsValues($request->getParameter('extra_fields'),$projects->getId(),'projects');
      }
      
      //send notification
      if($sendNofification==true && strlen($projects->getTeam())>0)
      {
        $sendTo = array();
        $sendFrom = array();
        
        $c = new Criteria();
        $c->add(UsersPeer::ACTIVE,1);
        $c->add(UsersPeer::ID,explode(',',$projects->getTeam()), Criteria::IN);
        $users_list = UsersPeer::doSelect($c);
        
        foreach($users_list as $users)
        {
          $sendTo[$users->getEmail()] = $users->getName();
        }
        
        $c = new Criteria();
        $c->add(UsersPeer::ID,$projects->getCreatedBy());
        $user = UsersPeer::doSelectOne($c);
        
        $sendFrom[$user->getEmail()] = $user->getName();
      
        require_once sfConfig::get('sf_lib_dir').'/vendor/swift_init.php';

        $subject = I18NText::__('New Project') . ': ' . $projects->getName();
        $body = $this->getComponent('projects','emailNewProject', array('projectId'=>$projects->getId()));

        UsersPeer::sendEmail($sendTo,$subject,$body, $sendFrom,$this->getUser());
      }
      
      //redirect to
      if($request->hasParameter('redirectTo'))
      {
        $this->redirect($request->getParameter('redirectTo') . '/index?projectId=' . $projects->getId());
      }
      else
      {
        $this->redirect('projects/index');
      }
    }
  }
  
 function executeExport(sfWebRequest $request)
  {
    //build header
    $sheet1Header = array('Name','Status','Type','Created By','Created At');

    //include extra fields names in header
    $c= new Criteria();
    $c->add(ExtraFieldsPeer::BIND_TYPE,'projects');
    $c->addAscendingOrderByColumn(ExtraFieldsPeer::SORT_ORDER);
    $c->addAscendingOrderByColumn(ExtraFieldsPeer::NAME);
    $extra_fields_list = ExtraFieldsPeer::doSelect($c);
    
    foreach($extra_fields_list as $extra_fields)
    {
      $sheet1Header = array_merge($sheet1Header,array($extra_fields->getName()));
    }
    
    $sheet1Header = array_merge($sheet1Header,array('Url'));
    
    $countSheetColumns = sizeof($sheet1Header);

    $sheet1 =  array(
      $sheet1Header,
    );
    
    
    //build data
    
    $export_items_list = explode('_',$request->getParameter('export_items'));
    
    $taskUrl = $request->getParameter('taskUrl');
                   
    $overallExtraFieldsTotal = array();
            
    foreach($export_items_list as $itemId)
    {
      $c = new Criteria();
      $c->add(ProjectsPeer::ID,$itemId);
      $projects_list = ProjectsPeer::doSelectJoinAll($c);
      $projects = current($projects_list);
               
      $sheet1Item = array(
        $projects->getName(),
        ($projects->getProjectsStatusId()>0 ? $projects->getProjectsStatus()->getName() : ''),
        ($projects->getProjectsTypesId()>0 ? $projects->getProjectsTypes()->getName() : ''),
        $projects->getUsers()->getName(),
        $projects->getCreatedAt()
      );
      
      //include extra fields in data
      $c= new Criteria();
      $c->add(ExtraFieldsPeer::BIND_TYPE,'projects');
      $c->addAscendingOrderByColumn(ExtraFieldsPeer::SORT_ORDER);
      $c->addAscendingOrderByColumn(ExtraFieldsPeer::NAME);
      $extra_fields_list = ExtraFieldsPeer::doSelect($c);

      foreach($extra_fields_list as $extra_fields)
      {
        $value = ExtraFieldsListPeer::getValueByBindId($itemId, $extra_fields->getId());
        $sheet1Item = array_merge($sheet1Item,array($value));
        
        if($value>0 && $extra_fields->getType()=='number')
        {          
          //get $overallExtraFieldsTotal
          if(!isset($overallExtraFieldsTotal[$extra_fields->getName()]))
          {
            $overallExtraFieldsTotal[$extra_fields->getName()] = $value;
          }
          else
          {
            $overallExtraFieldsTotal[$extra_fields->getName()] += $value;
          }
        }
      }
      
      $sheet1Item = array_merge($sheet1Item,array($taskUrl . '?projectId=' . $projects->getId()));
      

      
      $sheet1[] = $sheet1Item;
    }
       
    
    //set $overallExtraFieldsTotal
    if(sizeof($overallExtraFieldsTotal)>0)
    {
      foreach($overallExtraFieldsTotal as $text=>$total)
      {
        $count_key = 0;
        foreach($sheet1Header as $value)
        {
          if($text==$value)
          {
            $sheet1[sizeof($sheet1)][$count_key] = 'Total: ' . $total;
          }
          $count_key++;
        }
      }
    }
    
    //echo "<pre>";
    //print_r($sheet1);
    
    //exit();
    
    chdir(sfConfig::get('sf_lib_dir') . '/phpxls');
    require_once 'Writer.php';
    chdir('..');

    $workbook = new Spreadsheet_Excel_Writer();
    
    $workbook->setVersion(8);

    $workbook->setCustomColor(24, 240, 240, 240);

    $format_und =& $workbook->addFormat();
    $format_und->setBottom(2);//thick
    $format_und->setBold();
    $format_und->setColor('black');
    $format_und->setFontFamily('Arial');
    $format_und->setSize(10);
    $format_und->setFgColor(24);

    $format_reg =& $workbook->addFormat();
    $format_reg->setColor('black');
    $format_reg->setFontFamily('Arial');
    $format_reg->setSize(10);
    
    $format_title =& $workbook->addFormat();
    $format_title->setBold();
    $format_title->setColor('black');
    $format_title->setFontFamily('Arial');
    $format_title->setSize(10);

    $arr = array(
          'Tasks'=>$sheet1,
          );

    foreach($arr as $wbname=>$rows)
    {
        $rowcount = count($rows);
        $colcount = count($rows[0]);

        $worksheet =& $workbook->addWorksheet("\xD0\x9B\xD0\xB8\xD1\x81\xD1\x82");
        
        $worksheet->setInputEncoding('UTF-8');

        $worksheet->setColumn(0,0, 40);
        $worksheet->setColumn(1,2, 15);//setColumn(startcol,endcol,float)
        $worksheet->setColumn(3,3,25);
        $worksheet->setColumn(4,4,25);
        $worksheet->setColumn(5,$countSheetColumns-2,20);
        $worksheet->setColumn($countSheetColumns-1,$countSheetColumns-1, 80);

        for( $j=0; $j<$rowcount; $j++ )
        {
            for($i=0; $i<$colcount;$i++)
            {
                $fmt  =& $format_reg;
                if ($j==0)
                    $fmt =& $format_und;



                if (isset($rows[$j][$i]))
                {
                  if(isset($rows[$j][0]))
                  if(strlen($rows[$j][0])>0 and !isset($rows[$j][3]))
                  {
                    $fmt =& $format_title;
                  }
                
                    $data=$rows[$j][$i];
                    $worksheet->writeString($j, $i, $data, $fmt);
                }
            }
        }
    }

    $workbook->send('ProjectsExport.xls');
    $workbook->close();
    exit();
  }
    
  public function executeMultipleEdit(sfWebRequest $request)
  {
    if ($request->isMethod('post'))
    {
      $selected_items = explode('_',$request->getParameter('selected_items'));      
      
      foreach($selected_items as $itemId)
      {
        $c = new Criteria();
        $c->add(ProjectsPeer::ID,$itemId);
        $projects = ProjectsPeer::doSelectOne($c);
        
        $project_fields = $request->getParameter('project_fields');
        
        foreach($project_fields as $key=>$value)
        {
          if($value>0)
          {
            $functionName = '';
            for($i=0; $i<strlen($key);$i++)
            {
               if($i==0)
               {
                 $functionName .= strtoupper($key[$i]);
               }
               elseif($key[$i]=='_')
               {
                  $i++;
                 $functionName .= strtoupper($key[$i]);
               }
               else
               {
                 $functionName .= $key[$i];
               }
            }

            $eval_str = '$projects->set' . $functionName . '("' . $value . '");';
            
            eval($eval_str);
          }
        }
        
        $projects->save();        

      }

       $this->redirect('projects/index');
    }
  
    $this->form = new ProjectsMultipleEditForm();
  }
}
