<?php

/**
 * tasksComments actions.
 *
 * @package    sf_sandbox
 * @subpackage tasksComments
 * @author     Your name here
 * @version    SVN: $Id: actions.class.php 12474 2008-10-31 10:41:27Z fabien $
 */
class tasksCommentsActions extends sfActions
{
  public function executeIndex(sfWebRequest $request)
  {
    $this->projectId = $request->getParameter('projectId');
    $this->tasksId = $request->getParameter('tasksId');

    $c = new Criteria();
    $c->add(TasksCommentsPeer::TASKS_ID, $this->tasksId );
    $c->addDescendingOrderByColumn(TasksCommentsPeer::CREATED_AT);
    $this->tasks_comments_list = TasksCommentsPeer::doSelectJoinAll($c);
    
    $c = new Criteria();
    $c->add(TasksPeer::ID,$this->tasksId);
    $tasks_list = TasksPeer::doSelectJoinAll($c);
    $this->task = current($tasks_list);
    
    if(strlen($this->task->getStartDate())>0 and strlen($this->task->getDueDate())>0)
    {
      if(TasksPeer::getDateTimestamp($this->task->getStartDate()) > TasksPeer::getDateTimestamp($this->task->getDueDate()))
      {
        $this->getUser()->setFlash('userNotices', I18NText::__('Error: Due Date can\'t be before Start Dates'));
      }
    }
    
    $response = $this->getResponse();
    $response->setTitle(sfConfig::get('app_app_short_name') . ' | ' . $this->task ->getName());
  }

  public function executeNew(sfWebRequest $request)
  {
    $this->form = new TasksCommentsForm();
    $this->form->setDefault('tasks_id', $request->getParameter('tasksId'));
    $this->form->setDefault('created_by', $this->getUser()->getAttribute('userId'));

    $tasks = TasksPeer::retrieveByPk($request->getParameter('tasksId'));
    $this->form->setDefault('tasks_status_id',$tasks->getTasksStatusId());

  }

  public function executeCreate(sfWebRequest $request)
  {
    $this->forward404Unless($request->isMethod('post'));

    $this->form = new TasksCommentsForm();

    $this->processForm($request, $this->form);

    $this->setTemplate('new');
  }

  public function executeEdit(sfWebRequest $request)
  {
    $this->forward404Unless($tasks_comments = TasksCommentsPeer::retrieveByPk($request->getParameter('id')), sprintf('Object tasks_comments does not exist (%s).', $request->getParameter('id')));
    $this->form = new TasksCommentsForm($tasks_comments);
  }

  public function executeUpdate(sfWebRequest $request)
  {
    $this->forward404Unless($request->isMethod('post') || $request->isMethod('put'));
    $this->forward404Unless($tasks_comments = TasksCommentsPeer::retrieveByPk($request->getParameter('id')), sprintf('Object tasks_comments does not exist (%s).', $request->getParameter('id')));
    $this->form = new TasksCommentsForm($tasks_comments);

    $this->processForm($request, $this->form);

    $this->setTemplate('edit');
  }

  public function executeDelete(sfWebRequest $request)
  {
    $request->checkCSRFProtection();

    $this->forward404Unless($tasks_comments = TasksCommentsPeer::retrieveByPk($request->getParameter('id')), sprintf('Object tasks_comments does not exist (%s).', $request->getParameter('id')));

    AttachmentsPeer::deleteAttachments('comments', $tasks_comments->getId());

    $tasks_comments->delete();

    $this->redirect('tasksComments/index?tasksId=' . $request->getParameter('tasksId') . '&projectId=' . $request->getParameter('projectId'));
  }

  protected function processForm(sfWebRequest $request, sfForm $form)
  {
    //insert attachments
    $attachments_files = array();
    $files = $request->getFiles();

    foreach($files['attachments'] as $key=>$file)
    {
      if(strlen($file['name'])>0)
      {
        $filename = rand(111111,999999)  . '-' . $file['name'];
        move_uploaded_file($file['tmp_name'], sfConfig::get('sf_upload_dir') . '/attachments/'  . $filename);
        $attachments_files[] = $filename;
      }
      else
      {
        $attachments_files[] = '';
      }
    }
  
    $form->bind($request->getParameter($form->getName()), $request->getFiles($form->getName()));
    if ($form->isValid())
    {
      $tasks_comments = $form->save();
      
      AttachmentsPeer::insertAttachments($request->getParameter('attachments_id'), $request->getParameter('attachments_info'),$attachments_files,$tasks_comments->getId(),'comments');

      //change task status
      $tasks = TasksPeer::retrieveByPk($request->getParameter('tasksId'));
      
      $updateClosedDateType = TasksPeer::getUpdateClosedDateType($tasks, $tasks_comments->getTasksStatusId());  
        
      if($updateClosedDateType == 'updateClosedDate')
      {
        $tasks->setClosedDate(date('Y-m-d'));
      }
      elseif($updateClosedDateType == 'clearClosedDate')
      {
        $tasks->setClosedDate(NULL);
      } 
      
      $tasks->setTasksStatusId($tasks_comments->getTasksStatusId());
      
      if($tasks_comments->getTasksPriorityId()>0)
      {
        $tasks->setTasksPriorityId($tasks_comments->getTasksPriorityId());
      }
      
      if(strlen($tasks_comments->getDueDate())>0)
      {
        $tasks->setDueDate($tasks_comments->getDueDate());
      }
      
      if($tasks_comments->getProgress()>0)
      {
        $tasks->setProgress($tasks_comments->getProgress());
      }
      
      $tasks->save();


      $project = ProjectsPeer::retrieveByPk($request->getParameter('projectId'));

      //send notification      
      $c = new Criteria();
      $c->add(TasksPeer::ID,$tasks_comments->getTasksId());
      $tasks = TasksPeer::doSelectOne($c);
      
      $v = TasksCommentsPeer::getSendToSendFrom($tasks_comments->getTasksId(), $tasks_comments->getCreatedBy());
      
      
      $sendTo = $v['sendTo'];
      $sendFrom = $v['sendFrom'];
                  
      if(sfConfig::get('app_notify_all_project_team')=='on')
      {
        $c = new Criteria();
        $c->add(UsersPeer::ACTIVE,1);
        $c->add(UsersPeer::ID,explode(',',$project->getTeam()), Criteria::IN);        
        $users_list = UsersPeer::doSelect($c);
        
        foreach($users_list as $users)
        {
          $sendTo[$users->getEmail()] = $users->getName();
        }
      }            
      
      if(sizeof($sendTo)>0)
      {
        require_once sfConfig::get('sf_lib_dir').'/vendor/swift_init.php';

        
        
        
        if(strlen(strip_tags($tasks_comments->getDescription()))==0)
        {
          $subject = I18NText::__('Status Updated') . ': ';
        }
        else
        {
          $subject = I18NText::__('New Comment') . ': ';
        } 
        
        $subject .= $project->getName() . ' - ' . $tasks->getName() . ($tasks_comments->getTasksStatusId()>0 ? ' [' . $tasks_comments->getTasksStatus()->getName() . ']' : '');
        
        $body = $this->getComponent('tasksComments','emailNewComment', array('projectId'=>$request->getParameter('projectId'), 'taskId' => $tasks_comments->getTasksId()));
                
        
        UsersPeer::sendEmail($sendTo,$subject,$body, $sendFrom,$this->getUser());
      }

             
      
      
      
      $this->redirect('tasksComments/index?tasksId=' . $request->getParameter('tasksId') . '&projectId=' . $request->getParameter('projectId'));
    }
  }
}
