<?php

/**
 * ticketsComments actions.
 *
 * @package    sf_sandbox
 * @subpackage ticketsComments
 * @author     Your name here
 * @version    SVN: $Id: actions.class.php 12474 2008-10-31 10:41:27Z fabien $
 */
class ticketsCommentsActions extends sfActions
{
  public function executeIndex(sfWebRequest $request)
  {
    $this->projectId = $request->getParameter('projectId');
    $this->ticketId = $request->getParameter('ticketId');
        
    
    $c = new Criteria();
    $c->add(TicketsCommentsPeer::TICKETS_ID,$this->ticketId);
    $c->addDescendingOrderByColumn(TicketsCommentsPeer::CREATED_AT);
    $this->tickets_comments_list = TicketsCommentsPeer::doSelect($c);
    
    $c = new Criteria();
    $c->add(TicketsPeer::ID,$this->ticketId);
    $this->ticket = TicketsPeer::doSelectOne($c);
    
    if($this->getUser()->hasCredential('allow_manage_tasks') && TicketsPeer::hasOpenRelatedTasks($this->ticketId, $this->projectId) && TicketsPeer::isClosed($this->ticketId))
    {
      $this->getUser()->setFlash('userNotices', I18NText::__('Warning: this ticket is closed but there are some open tasks related to this ticket. Please check related tasks.'));
    }
    
  }

  public function executeNew(sfWebRequest $request)
  {
    $this->form = new TicketsCommentsForm();
    
    $this->form->setDefault('tickets_id', $request->getParameter('ticketId'));
    $this->form->setDefault('users_id', $this->getUser()->getAttribute('userId'));

    $ticket = TicketsPeer::retrieveByPk($request->getParameter('ticketId'));
    $this->form->setDefault('tickets_status_id',$ticket->getTicketsStatusId());
  }

  public function executeCreate(sfWebRequest $request)
  {
    $this->forward404Unless($request->isMethod('post'));

    $this->form = new TicketsCommentsForm();

    $this->processForm($request, $this->form);

    $this->setTemplate('new');
  }

  public function executeEdit(sfWebRequest $request)
  {
    $this->forward404Unless($tickets_comments = TicketsCommentsPeer::retrieveByPk($request->getParameter('id')), sprintf('Object tickets_comments does not exist (%s).', $request->getParameter('id')));
    $this->form = new TicketsCommentsForm($tickets_comments);
  }

  public function executeUpdate(sfWebRequest $request)
  {
    $this->forward404Unless($request->isMethod('post') || $request->isMethod('put'));
    $this->forward404Unless($tickets_comments = TicketsCommentsPeer::retrieveByPk($request->getParameter('id')), sprintf('Object tickets_comments does not exist (%s).', $request->getParameter('id')));
    $this->form = new TicketsCommentsForm($tickets_comments);

    $this->processForm($request, $this->form);

    $this->setTemplate('edit');
  }

  public function executeDelete(sfWebRequest $request)
  {
    $request->checkCSRFProtection();

    $this->forward404Unless($tickets_comments = TicketsCommentsPeer::retrieveByPk($request->getParameter('id')), sprintf('Object tickets_comments does not exist (%s).', $request->getParameter('id')));
    $tickets_comments->delete();

    //$this->redirect('ticketsComments/index');
    $this->redirect('ticketsComments/index?ticketId='.$request->getParameter('ticketId') . '&projectId=' . $request->getParameter('projectId'));
  }

  protected function processForm(sfWebRequest $request, sfForm $form)
  {  
    //insert attachments
    $attachments_files = array();
    $files = $request->getFiles();

    foreach($files['attachments'] as $key=>$file)
    {
      if(strlen($file['name'])>0)
      {
        $filename = rand(111111,999999)  . '-' . $file['name'];
        move_uploaded_file($file['tmp_name'], sfConfig::get('sf_upload_dir') . '/attachments/'  . $filename);
        $attachments_files[] = $filename;
      }
      else
      {
        $attachments_files[] = '';
      }
    }
      
    $form->bind($request->getParameter($form->getName()), $request->getFiles($form->getName()));
    if ($form->isValid())
    {          
      //save form
      $tickets_comments = $form->save();
      
      //save attachemts
      AttachmentsPeer::insertAttachments($request->getParameter('attachments_id'), $request->getParameter('attachments_info'),$attachments_files,$tickets_comments->getId(),'ticketsComments');

      //change task status
      $tickets = TicketsPeer::retrieveByPk($request->getParameter('ticketId'));
      $tickets->setTicketsStatusId($tickets_comments->getTicketsStatusId());
      $tickets->save();

      //send notification            
      $v = TicketsCommentsPeer::getSendToSendFrom($request->getParameter('projectId'), $tickets_comments->getTicketsId(),  $tickets_comments->getUsersId());
      $sendTo = $v['sendTo'];
      $sendFrom = $v['sendFrom'];
      
      if(sizeof($sendTo)>0)
      {
        require_once sfConfig::get('sf_lib_dir').'/vendor/swift_init.php';

        if(strlen(strip_tags($tickets->getDescription()))==0)
        {
          $subject = I18NText::__('Ticket Status Updated') . ': ';
        }
        else
        {
          $subject = I18NText::__('New Ticket Comment') . ': ';
        } 
         
        $subject .= $tickets->getProjects()->getName() . ' - ' . $tickets->getName() . ($tickets->getTicketsStatusId()>0 ?  ' [' . $tickets->getTicketsStatus()->getName() . ']':'');
        $body = $this->getComponent('ticketsComments','emailNewComment', array('projectId'=>$request->getParameter('projectId'), 'ticketId' => $tickets_comments->getTicketsId()));

        UsersPeer::sendEmail($sendTo,$subject,$body, $sendFrom,$this->getUser());
      }
      
      //redirect to
      $this->redirect('ticketsComments/index?ticketId='.$tickets_comments->getTicketsId() . '&projectId=' . $request->getParameter('projectId'));
    }
  }
}
