
# This is a fix for InnoDB in MySQL >= 4.1.x
# It "suspends judgement" for fkey relationships until are tables are set.
SET FOREIGN_KEY_CHECKS = 0;

#-----------------------------------------------------------------------------
#-- attachments
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `attachments`;


CREATE TABLE `attachments`
(
	`id` INTEGER(11)  NOT NULL AUTO_INCREMENT,
	`bind_type` VARCHAR(64)  NOT NULL,
	`bind_id` INTEGER(11) NOT NULL,
	`file` VARCHAR(255),
	`info` VARCHAR(255),
	PRIMARY KEY (`id`),
	UNIQUE KEY `id` (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- configuration
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `configuration`;


CREATE TABLE `configuration`
(
	`id` INTEGER(11)  NOT NULL AUTO_INCREMENT,
	`key` VARCHAR(255)  NOT NULL,
	`value` TEXT,
	PRIMARY KEY (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- discussions
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `discussions`;


CREATE TABLE `discussions`
(
	`id` INTEGER(11)  NOT NULL AUTO_INCREMENT,
	`projects_id` INTEGER(11) NOT NULL,
	`users_id` INTEGER(11) NOT NULL,
	`discussions_status_id` INTEGER(11),
	`name` VARCHAR(255)  NOT NULL,
	`description` TEXT,
	PRIMARY KEY (`id`),
	KEY `fk_discussions_projects`(`projects_id`),
	KEY `fk_discussions_users`(`users_id`),
	KEY `fk_discussions_discussions_status`(`discussions_status_id`),
	CONSTRAINT `discussions_FK_1`
		FOREIGN KEY (`projects_id`)
		REFERENCES `projects` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	CONSTRAINT `discussions_FK_2`
		FOREIGN KEY (`users_id`)
		REFERENCES `users` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	CONSTRAINT `discussions_FK_3`
		FOREIGN KEY (`discussions_status_id`)
		REFERENCES `discussions_status` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- discussions_comments
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `discussions_comments`;


CREATE TABLE `discussions_comments`
(
	`id` INTEGER(11)  NOT NULL AUTO_INCREMENT,
	`discussions_id` INTEGER(11) NOT NULL,
	`users_id` INTEGER(11) NOT NULL,
	`description` TEXT,
	`created_at` DATETIME,
	PRIMARY KEY (`id`),
	KEY `fk_discussions_comments_discussions`(`discussions_id`),
	KEY `fk_discussions_comments_users`(`users_id`),
	CONSTRAINT `discussions_comments_FK_1`
		FOREIGN KEY (`discussions_id`)
		REFERENCES `discussions` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	CONSTRAINT `discussions_comments_FK_2`
		FOREIGN KEY (`users_id`)
		REFERENCES `users` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- discussions_status
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `discussions_status`;


CREATE TABLE `discussions_status`
(
	`id` INTEGER(11)  NOT NULL AUTO_INCREMENT,
	`name` VARCHAR(255),
	`sort_order` INTEGER(11) default 0,
	`default_value` TINYINT(1),
	`active` TINYINT(1),
	PRIMARY KEY (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- extra_fields
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `extra_fields`;


CREATE TABLE `extra_fields`
(
	`id` INTEGER(11)  NOT NULL AUTO_INCREMENT,
	`name` VARCHAR(255)  NOT NULL,
	`bind_type` VARCHAR(64)  NOT NULL,
	`type` VARCHAR(64),
	`sort_order` INTEGER(11) default 0,
	`active` TINYINT(1),
	PRIMARY KEY (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- extra_fields_list
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `extra_fields_list`;


CREATE TABLE `extra_fields_list`
(
	`id` INTEGER(11)  NOT NULL AUTO_INCREMENT,
	`extra_fields_id` INTEGER(11) NOT NULL,
	`bind_id` INTEGER(11) NOT NULL,
	`value` TEXT  NOT NULL,
	PRIMARY KEY (`id`),
	KEY `fk_extra_fields_list_extra_fields`(`extra_fields_id`),
	CONSTRAINT `extra_fields_list_FK_1`
		FOREIGN KEY (`extra_fields_id`)
		REFERENCES `extra_fields` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- phases
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `phases`;


CREATE TABLE `phases`
(
	`id` INTEGER(11)  NOT NULL AUTO_INCREMENT,
	`name` VARCHAR(255)  NOT NULL,
	`default_values` TEXT  NOT NULL,
	PRIMARY KEY (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- phases_status
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `phases_status`;


CREATE TABLE `phases_status`
(
	`id` INTEGER(11)  NOT NULL AUTO_INCREMENT,
	`name` VARCHAR(255)  NOT NULL,
	`sort_order` INTEGER(11) default 0,
	`default_value` TINYINT(1),
	`active` TINYINT(1),
	PRIMARY KEY (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- projects
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `projects`;


CREATE TABLE `projects`
(
	`id` INTEGER(11)  NOT NULL AUTO_INCREMENT,
	`projects_status_id` INTEGER(11),
	`projects_types_id` INTEGER(11),
	`created_by` INTEGER(11),
	`name` VARCHAR(255)  NOT NULL,
	`description` TEXT,
	`team` TEXT,
	`created_at` DATETIME,
	PRIMARY KEY (`id`),
	KEY `fk_projects_projects_status`(`projects_status_id`),
	KEY `fk_projects_project_types`(`projects_types_id`),
	KEY `fk_projects_pople`(`created_by`),
	CONSTRAINT `projects_FK_1`
		FOREIGN KEY (`projects_status_id`)
		REFERENCES `projects_status` (`id`)
		ON UPDATE SET NULL
		ON DELETE SET NULL,
	CONSTRAINT `projects_FK_2`
		FOREIGN KEY (`projects_types_id`)
		REFERENCES `projects_types` (`id`)
		ON UPDATE SET NULL
		ON DELETE SET NULL,
	CONSTRAINT `projects_FK_3`
		FOREIGN KEY (`created_by`)
		REFERENCES `users` (`id`)
		ON UPDATE SET NULL
		ON DELETE SET NULL
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- projects_comments
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `projects_comments`;


CREATE TABLE `projects_comments`
(
	`id` INTEGER(11)  NOT NULL AUTO_INCREMENT,
	`projects_id` INTEGER(11) NOT NULL,
	`created_by` INTEGER(11) NOT NULL,
	`description` TEXT,
	`created_at` DATETIME,
	PRIMARY KEY (`id`),
	KEY `fk_projects_comments_projects`(`projects_id`),
	KEY `fk_projects_comments_pople`(`created_by`),
	CONSTRAINT `projects_comments_FK_1`
		FOREIGN KEY (`projects_id`)
		REFERENCES `projects` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	CONSTRAINT `projects_comments_FK_2`
		FOREIGN KEY (`created_by`)
		REFERENCES `users` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- projects_phases
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `projects_phases`;


CREATE TABLE `projects_phases`
(
	`id` INTEGER(11)  NOT NULL AUTO_INCREMENT,
	`projects_id` INTEGER(11) NOT NULL,
	`phases_status_id` INTEGER(11),
	`name` VARCHAR(255)  NOT NULL,
	`due_date` DATE,
	PRIMARY KEY (`id`),
	KEY `fk_projects_phases_projects`(`projects_id`),
	KEY `fk_projects_phases_phases_status`(`phases_status_id`),
	CONSTRAINT `projects_phases_FK_1`
		FOREIGN KEY (`projects_id`)
		REFERENCES `projects` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	CONSTRAINT `projects_phases_FK_2`
		FOREIGN KEY (`phases_status_id`)
		REFERENCES `phases_status` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- projects_status
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `projects_status`;


CREATE TABLE `projects_status`
(
	`id` INTEGER(11)  NOT NULL AUTO_INCREMENT,
	`name` VARCHAR(255)  NOT NULL,
	`sort_order` INTEGER(11) default 0,
	`default_value` TINYINT(1),
	`active` TINYINT(1),
	PRIMARY KEY (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- projects_types
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `projects_types`;


CREATE TABLE `projects_types`
(
	`id` INTEGER(11)  NOT NULL AUTO_INCREMENT,
	`name` VARCHAR(255)  NOT NULL,
	`sort_order` INTEGER(11) default 0,
	`active` TINYINT(1),
	PRIMARY KEY (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- tasks
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `tasks`;


CREATE TABLE `tasks`
(
	`id` INTEGER(11)  NOT NULL AUTO_INCREMENT,
	`projects_id` INTEGER(11) NOT NULL,
	`tasks_status_id` INTEGER(11) NOT NULL,
	`tasks_priority_id` INTEGER(11) NOT NULL,
	`tasks_type_id` INTEGER(11),
	`tasks_label_id` INTEGER(11),
	`tasks_groups_id` INTEGER(11),
	`projects_phases_id` INTEGER(11),
	`versions_id` INTEGER(11),
	`created_by` INTEGER(11) NOT NULL,
	`name` VARCHAR(255)  NOT NULL,
	`description` TEXT,
	`assigned_to` INTEGER(11) NOT NULL,
	`estimated_time` FLOAT,
	`due_date` DATE,
	`created_at` DATETIME,
	PRIMARY KEY (`id`),
	KEY `fk_tasks_projects`(`projects_id`),
	KEY `fk_tasks_task_status`(`tasks_status_id`),
	KEY `fk_tasks_task_type`(`tasks_type_id`),
	KEY `fk_tasks_task_label`(`tasks_label_id`),
	KEY `fk_tasks_projects_phases`(`projects_phases_id`),
	KEY `fk_tasks_pople`(`created_by`),
	KEY `fk_tasks_tasks_groups`(`tasks_groups_id`),
	KEY `fk_tasks_versions`(`versions_id`),
	KEY `fk_tasks_tasks_priority`(`tasks_priority_id`),
	CONSTRAINT `tasks_FK_1`
		FOREIGN KEY (`projects_id`)
		REFERENCES `projects` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	CONSTRAINT `tasks_FK_2`
		FOREIGN KEY (`tasks_status_id`)
		REFERENCES `tasks_status` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	CONSTRAINT `tasks_FK_3`
		FOREIGN KEY (`tasks_priority_id`)
		REFERENCES `tasks_priority` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	CONSTRAINT `tasks_FK_4`
		FOREIGN KEY (`tasks_type_id`)
		REFERENCES `tasks_types` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	CONSTRAINT `tasks_FK_5`
		FOREIGN KEY (`tasks_label_id`)
		REFERENCES `tasks_labels` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	CONSTRAINT `tasks_FK_6`
		FOREIGN KEY (`tasks_groups_id`)
		REFERENCES `tasks_groups` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	CONSTRAINT `tasks_FK_7`
		FOREIGN KEY (`projects_phases_id`)
		REFERENCES `projects_phases` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	CONSTRAINT `tasks_FK_8`
		FOREIGN KEY (`versions_id`)
		REFERENCES `versions` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	CONSTRAINT `tasks_FK_9`
		FOREIGN KEY (`created_by`)
		REFERENCES `users` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- tasks_comments
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `tasks_comments`;


CREATE TABLE `tasks_comments`
(
	`id` INTEGER(11)  NOT NULL AUTO_INCREMENT,
	`tasks_id` INTEGER(11) NOT NULL,
	`created_by` INTEGER(11) NOT NULL,
	`tasks_status_id` INTEGER(11),
	`description` TEXT,
	`created_at` DATETIME,
	PRIMARY KEY (`id`),
	KEY `fk_tasks_comments_pople`(`created_by`),
	KEY `fk_tasks_comments_tasks`(`tasks_id`),
	KEY `fk_tasks_comments_status`(`tasks_status_id`),
	CONSTRAINT `tasks_comments_FK_1`
		FOREIGN KEY (`tasks_id`)
		REFERENCES `tasks` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	CONSTRAINT `tasks_comments_FK_2`
		FOREIGN KEY (`created_by`)
		REFERENCES `users` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	CONSTRAINT `tasks_comments_FK_3`
		FOREIGN KEY (`tasks_status_id`)
		REFERENCES `tasks_status` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- tasks_groups
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `tasks_groups`;


CREATE TABLE `tasks_groups`
(
	`id` INTEGER(11)  NOT NULL AUTO_INCREMENT,
	`projects_id` INTEGER(11) NOT NULL,
	`name` VARCHAR(255)  NOT NULL,
	PRIMARY KEY (`id`),
	KEY `fk_tasks_groups_projects`(`projects_id`),
	CONSTRAINT `tasks_groups_FK_1`
		FOREIGN KEY (`projects_id`)
		REFERENCES `projects` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- tasks_labels
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `tasks_labels`;


CREATE TABLE `tasks_labels`
(
	`id` INTEGER(11)  NOT NULL AUTO_INCREMENT,
	`name` VARCHAR(255)  NOT NULL,
	`sort_order` INTEGER(11) default 0,
	`default_value` TINYINT(1),
	`active` TINYINT(1),
	PRIMARY KEY (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- tasks_priority
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `tasks_priority`;


CREATE TABLE `tasks_priority`
(
	`id` INTEGER(11)  NOT NULL AUTO_INCREMENT,
	`name` VARCHAR(255)  NOT NULL,
	`icon` VARCHAR(64),
	`sort_order` INTEGER(11),
	`default_value` TINYINT(1),
	`active` TINYINT(1),
	PRIMARY KEY (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- tasks_status
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `tasks_status`;


CREATE TABLE `tasks_status`
(
	`id` INTEGER(11)  NOT NULL AUTO_INCREMENT,
	`name` VARCHAR(255)  NOT NULL,
	`group` VARCHAR(64)  NOT NULL,
	`sort_order` INTEGER(11) default 0,
	`default_value` TINYINT(1),
	`active` TINYINT(1),
	PRIMARY KEY (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- tasks_types
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `tasks_types`;


CREATE TABLE `tasks_types`
(
	`id` INTEGER(11)  NOT NULL AUTO_INCREMENT,
	`name` VARCHAR(255)  NOT NULL,
	`sort_order` INTEGER(11) default 0,
	`default_value` TINYINT(1),
	`active` TINYINT(1),
	PRIMARY KEY (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- user_reports
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `user_reports`;


CREATE TABLE `user_reports`
(
	`id` INTEGER(11)  NOT NULL AUTO_INCREMENT,
	`users_id` INTEGER(11) NOT NULL,
	`name` VARCHAR(255)  NOT NULL,
	`display_on_home` TINYINT(1),
	`projects_id` TEXT,
	`assigned_to` TEXT,
	`tasks_status_id` TEXT,
	`tasks_type_id` TEXT,
	`tasks_label_id` TEXT,
	`due_date_from` DATE,
	`due_date_to` DATE,
	`created_from` DATE,
	`created_to` DATE,
	PRIMARY KEY (`id`),
	KEY `fk_user_reports_users`(`users_id`),
	CONSTRAINT `user_reports_FK_1`
		FOREIGN KEY (`users_id`)
		REFERENCES `users` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- users
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `users`;


CREATE TABLE `users`
(
	`id` INTEGER(11)  NOT NULL AUTO_INCREMENT,
	`users_group_id` INTEGER(11) NOT NULL,
	`name` VARCHAR(255)  NOT NULL,
	`photo` VARCHAR(64),
	`email` VARCHAR(255)  NOT NULL,
	`password` VARCHAR(64)  NOT NULL,
	`active` TINYINT(1),
	PRIMARY KEY (`id`),
	KEY `fk_pople_people_group`(`users_group_id`),
	CONSTRAINT `users_FK_1`
		FOREIGN KEY (`users_group_id`)
		REFERENCES `users_groups` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- users_groups
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `users_groups`;


CREATE TABLE `users_groups`
(
	`id` INTEGER(11)  NOT NULL AUTO_INCREMENT,
	`name` VARCHAR(255)  NOT NULL,
	`allow_view_all` TINYINT(1),
	`allow_manage_projects` TINYINT(1),
	`allow_manage_users` TINYINT(1),
	`allow_manage_configuration` TINYINT(1),
	PRIMARY KEY (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- versions
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `versions`;


CREATE TABLE `versions`
(
	`id` INTEGER(11)  NOT NULL AUTO_INCREMENT,
	`projects_id` INTEGER(11) NOT NULL,
	`versions_status_id` INTEGER(11),
	`name` VARCHAR(255)  NOT NULL,
	`description` TEXT,
	`due_date` DATE,
	PRIMARY KEY (`id`),
	KEY `fk_versions_versions_status`(`versions_status_id`),
	KEY `fk_versions_projects`(`projects_id`),
	CONSTRAINT `versions_FK_1`
		FOREIGN KEY (`projects_id`)
		REFERENCES `projects` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	CONSTRAINT `versions_FK_2`
		FOREIGN KEY (`versions_status_id`)
		REFERENCES `versions_status` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- versions_status
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `versions_status`;


CREATE TABLE `versions_status`
(
	`id` INTEGER(11)  NOT NULL AUTO_INCREMENT,
	`name` VARCHAR(255)  NOT NULL,
	`sort_order` INTEGER(11) default 0,
	`default_value` TINYINT(1),
	`active` TINYINT(1),
	PRIMARY KEY (`id`)
)Type=InnoDB;

# This restores the fkey checks, after having unset them earlier
SET FOREIGN_KEY_CHECKS = 1;
