<?php

class TasksMultipleEditForm extends sfForm
{
  public function configure()
  {
    $projectId = $this->getOption('projectId');
    $user = $this->getOption('user');
    
    $this->widgetSchema['tasks_status_id'] =  new sfWidgetFormChoice(array('choices' => TasksStatusPeer::getGroupedStatusList(true)));
    
    $c= new Criteria();
    $c->add(TasksPriorityPeer::ACTIVE,1);
    $c->addAscendingOrderByColumn(TasksPriorityPeer::SORT_ORDER);
    $c->addAscendingOrderByColumn(TasksPriorityPeer::NAME);
    $this->widgetSchema['tasks_priority_id'] =  new sfWidgetFormPropelChoice(array('model' => 'TasksPriority', 'add_empty' => true,'criteria' => $c));
    
    $this->widgetSchema['due_date'] = new sfWidgetFormInputDateTag();
    
    $c= new Criteria();
    $c->add(TasksLabelsPeer::ACTIVE,1);
    $c->addAscendingOrderByColumn(TasksLabelsPeer::SORT_ORDER);
    $c->addAscendingOrderByColumn(TasksLabelsPeer::NAME);
    $this->widgetSchema['tasks_label_id'] =  new sfWidgetFormPropelChoice(array('model' => 'TasksLabels', 'add_empty' => true,'criteria' => $c));

    $c= new Criteria();
    $c->add(TasksTypesPeer::ACTIVE,1);
    $c->addAscendingOrderByColumn(TasksTypesPeer::SORT_ORDER);
    $c->addAscendingOrderByColumn(TasksTypesPeer::NAME);
    $this->widgetSchema['tasks_type_id'] =  new sfWidgetFormPropelChoice(array('model' => 'TasksTypes', 'add_empty' => true,'criteria' => $c));

    

    $c = new Criteria();
    $c->add(VersionsPeer::PROJECTS_ID, $projectId);
    $countVersions = VersionsPeer::doCount($c);
    $this->setOption('countVersions',$countVersions);

    $c = new Criteria();
    $c->add(TasksGroupsPeer::PROJECTS_ID, $projectId);
    $countTasksGroups = TasksGroupsPeer::doCount($c);
    $this->setOption('countTasksGroups',$countTasksGroups);

    $c = new Criteria();
    $c->add(ProjectsPhasesPeer::PROJECTS_ID, $projectId);
    $countProjectsPhases = ProjectsPhasesPeer::doCount($c);
    $this->setOption('countProjectsPhases',$countProjectsPhases);

    if($countTasksGroups>0)
    {
      $c = new Criteria();
      $c->add(TasksGroupsPeer::PROJECTS_ID,$projectId);
      $this->widgetSchema['tasks_groups_id'] = new sfWidgetFormPropelChoice(array('model' => 'TasksGroups', 'add_empty' => true,'criteria' => $c));
    }
    else
    {
      $this->widgetSchema['tasks_groups_id'] = new sfWidgetFormInputHidden();
    }

    if($countProjectsPhases>0)
    {
      $c = new Criteria();
      $c->add(ProjectsPhasesPeer::PROJECTS_ID,$projectId);
      $this->widgetSchema['projects_phases_id'] = new sfWidgetFormPropelChoice(array('model' => 'ProjectsPhases', 'add_empty' => true,'criteria' => $c));
    }
    else
    {
      $this->widgetSchema['projects_phases_id'] = new sfWidgetFormInputHidden();
    }

    if($countVersions>0)
    {
      $c = new Criteria();
      $c->add(VersionsPeer::PROJECTS_ID,$projectId);
      $this->widgetSchema['versions_id'] = new sfWidgetFormPropelChoice(array('model' => 'Versions', 'add_empty' => true,'criteria' => $c));
    }
    else
    {
      $this->widgetSchema['versions_id'] = new sfWidgetFormInputHidden();
    }

    $c = new Criteria();
    $c->add(ProjectsPeer::ID, $projectId);
    $projects = ProjectsPeer::doSelect($c);
    $project = current($projects);

    $c = new Criteria();
    $c->add(UsersPeer::ACTIVE,1);
    $c->add(UsersPeer::ID,explode(',',$project->getTeam()), Criteria::IN);
    $this->widgetSchema['assigned_to'] = new sfWidgetFormPropelChoice(array('model' => 'Users', 'add_empty' => true,'criteria' => $c));

    $c = new Criteria();
    $c->add(UsersPeer::ACTIVE,1);
    $c->add(UsersPeer::ID,explode(',',$project->getTeam()), Criteria::IN);
    $this->widgetSchema['created_by'] = new sfWidgetFormPropelChoice(array('model' => 'Users', 'add_empty' => true,'criteria' => $c));
    
    $c= new Criteria();

    if(!$user->hasCredential('allow_view_all'))
    {
      $c->add('','(' . ProjectsPeer::CREATED_BY . '=' . $user->getAttribute('userId') . " or FIND_IN_SET(" . $user->getAttribute('userId') . "," . ProjectsPeer::TEAM . "))", Criteria::CUSTOM);
    }

    $c->addAscendingOrderByColumn(ProjectsPeer::NAME);
    $this->widgetSchema['projects_id'] =  new sfWidgetFormPropelChoice(array('model' => 'Projects', 'add_empty' => true,'criteria' => $c));
    
    $this->widgetSchema->setNameFormat('tasks_fields[%s]');


    $this->widgetSchema->setLabels(array('tasks_status_id'    => 'Status',
                                         'tasks_priority_id'  => 'Priority',
                                         'tasks_type_id'      => 'Type',
                                         'tasks_label_id'     => 'Label',
                                         'tasks_groups_id'    => 'Group',
                                         'projects_phases_id' => 'Phase',
                                         'versions_id'        => 'Version',
                                         'projects_id'        => 'Move To Project',
                                         ));

  }
}

?>
