<?php

class TasksCommentsPeer extends BaseTasksCommentsPeer
{
  public static function getNameLastCommented($taskId)
  {
    $c = new Criteria();
    $c->add(TasksCommentsPeer::TASKS_ID, $taskId);
    $c->addDescendingOrderByColumn(TasksCommentsPeer::CREATED_AT);
    $c->setLimit(1);
    if($tasks_comments_list = TasksCommentsPeer::doSelectJoinAll($c))
    {
      $tasks_comments = current($tasks_comments_list);

      if($tasks_comments->getUsers())
      {
        return $tasks_comments->getUsers()->getName();
      }
      else
      {
        return '';
      }
      
    }
    
    return '';
  }
  
  public static function getTextLastCommented($taskId)
  {
    $c = new Criteria();
    $c->add(TasksCommentsPeer::TASKS_ID, $taskId);
    $c->addDescendingOrderByColumn(TasksCommentsPeer::CREATED_AT);
    $c->setLimit(1);
    if($tasks_comments_list = TasksCommentsPeer::doSelectJoinAll($c))
    {
      $tasks_comments = current($tasks_comments_list);
            
      $comments_details =  replaceTextToLinks($tasks_comments->getDescription());
                  
      if(strlen(strip_tags($comments_details))==0) $comments_details = '';
      
      $comments_details .= get_component('attachments','attachmentsValuesList', array('bindType'=>'comments', 'bindId'=>$tasks_comments->getId()));
      
      $comments_details .= '<ul class="listInfoBlock">';
      
      if($tasks_comments->getTasksStatusId()>0)
      {
        $comments_details .= '<li>' . I18NText::__('Task Status') . ': ' . $tasks_comments->getTasksStatus()->getName() . '</li>';
      }
      
      if($tasks_comments->getTasksPriorityId()>0)
      {
        $comments_details .= '<li>' . I18NText::__('Task Priority') . ': ' . $tasks_comments->getTasksPriority()->getName() . '</li>';
      }
      
      if(strlen($tasks_comments->getDueDate())>0)
      {
        $comments_details .= '<li>' . I18NText::__('Due Date') . ': ' . shortDateFormat($tasks_comments->getDueDate()) . '</li>';
      }
      
      if($tasks_comments->getWorkedHours()>0)
      {
        $comments_details .= '<li>' . I18NText::__('Worked Hours') . ': ' . $tasks_comments->getWorkedHours() . '</li>';
      }
      
      $comments_details .= '<div>';
    
      return str_replace(array("\n","\r","\n\r"),'',$comments_details);
    }
    
    return '';
  }
  
  public static function getSendToSendFrom($taskId, $userId)
  {
    $c = new Criteria();
    $c->add(TasksPeer::ID,$taskId);
    $tasks = TasksPeer::doSelectOne($c);
    
    $sendTo = array();
    $sendFrom = array();

    $c = new Criteria();
    $c->add(UsersPeer::ID,$userId);
    $user = UsersPeer::doSelectOne($c);

    $sendFrom[$user->getEmail()] = $user->getName();

    $c = new Criteria();
    $c->add(UsersPeer::ID,explode(',',$tasks->getAssignedTo()),CRITERIA::IN);
    $assignedToList = UsersPeer::doSelect($c);
    foreach($assignedToList  as $assignedTo)
    {
      if($assignedTo->getEmail() != $user->getEmail())
      {
        $sendTo[$assignedTo->getEmail()] = $assignedTo->getName();
      }
    }

    $c = new Criteria();
    $c->add(UsersPeer::ID,$tasks->getCreatedBy());
    if($createdBy = UsersPeer::doSelectOne($c))
    {
      if($createdBy->getEmail() != $user->getEmail())
      {
        $sendTo[$createdBy->getEmail()] = $createdBy->getName();
      }
    }
          
    return array('sendTo'=> $sendTo, 'sendFrom'=> $sendFrom);  
  }
}
