<?php

class UsersPeer extends BaseUsersPeer
{

  public static function clearUsersFilters($user)
  {
     /**
     * clear tasks filters
     */
     $user->getAttributeHolder()->remove('filterTasksByStatusGroupId');
     $user->getAttributeHolder()->remove('filterTasksByStatusId');
     $user->getAttributeHolder()->remove('filterTasksByGroupsId');
     $user->getAttributeHolder()->remove('filterTasksByPhasesId');
     $user->getAttributeHolder()->remove('filterTasksByVersionsId');
     $user->getAttributeHolder()->remove('filterTasksByAssignedId');
     $user->getAttributeHolder()->remove('orderTasksBy');
     
     /**
     * clear tickets filters
     */
     $user->getAttributeHolder()->remove('filterTicketsByStatusGroupId');
     $user->getAttributeHolder()->remove('filterTicketsByStatusId');
     $user->getAttributeHolder()->remove('filterTicketsByTypeId');
     $user->getAttributeHolder()->remove('filterTicketsByDepartmentId');
     
  }
  public static function getMyOpenProjects($userId, $allow_view_all)
  {
    $dafaultStatusId = ProjectsStatusPeer::getDafaultStatusId();
    
    if($dafaultStatusId>0)
    {
      $c = new Criteria();
      $c->add('',"FIND_IN_SET(" . $userId . "," . ProjectsPeer::TEAM . ")", Criteria::CUSTOM);
      $c->add(ProjectsPeer::PROJECTS_STATUS_ID, $dafaultStatusId);
      $c->addAscendingOrderByColumn(ProjectsPeer::NAME);
      $projects_list = ProjectsPeer::doSelectJoinAll($c);
      
      return $projects_list;
    }
    else
    {
      return false;
    }
  }
  
  public static function getUserListForSelect()
  {
    $c = new Criteria();
    $c->add(UsersPeer::ACTIVE,1);
    $c->addAscendingOrderByColumn(UsersGroupsPeer::NAME);
    $users_list = UsersPeer::doSelectJoinAll($c);
    
    $grouped_users_list = array();
    $grouped_users_list[] = '';
    
    foreach($users_list as $users)
    {
      $grouped_users_list[$users->getUsersGroups()->getName()][$users->getId()] = '&nbsp;&nbsp;&nbsp;' . $users->getName() . ' (' . $users->getEmail() . ')';
    }
    
    return $grouped_users_list;
  }
  
  
  public static function getGroupedUserList()
  {
    $c = new Criteria();
    $c->add(UsersPeer::ACTIVE,1);
    $c->addAscendingOrderByColumn(UsersGroupsPeer::NAME);
    $c->addAscendingOrderByColumn(UsersPeer::NAME);
    $users_list = UsersPeer::doSelectJoinAll($c);
    
    $grouped_users_list = array();
    
    foreach($users_list as $users)
    {
      $grouped_users_list[$users->getUsersGroupId()][$users->getUsersGroups()->getName()][$users->getId()] = $users->getName() . ' (' . $users->getEmail() . ')';
    }
    
    return $grouped_users_list;
  }
  
  public static function getUserNameById($id)
  {
    $c = new Criteria();
    $c->add(UsersPeer::ID,$id);
    if($users = UsersPeer::doSelectOne($c))
    {
      return $users->getName();
    }
  }
  
  /**
   * @param  array  $to       //array('receiver@domain.org', 'other@domain.org' => 'A name')
   * @param  string $subject
   * @param  string $body
   * @param  array  $from     //array('john@doe.com' => 'John Doe')
   */
  public static function sendEmail($to, $subject, $body, $from,$user = false)
  {            
    if(strlen(sfConfig::get('app_email_label'))>0)
    {
      $subject = sfConfig::get('app_email_label') . ' ' . $subject;
    }
  
    if(sfConfig::get('app_use_single_email')=='on')
    {
      if(strlen(sfConfig::get('app_single_email_addres_from'))>0 and strlen(sfConfig::get('app_single_name_from'))>0)
      {
        $from = array(sfConfig::get('app_single_email_addres_from')=>sfConfig::get('app_single_name_from'));
      }
    }
    
    if(sfConfig::get('app_use_smtp')=='on')
    {
      //Create the Transport
      $transport = Swift_SmtpTransport::newInstance(sfConfig::get('app_smtp_server'), sfConfig::get('app_smtp_port'))
        ->setUsername(sfConfig::get('app_smtp_login'))
        ->setPassword(sfConfig::get('app_smtp_pass'))
        ;
        
      if(strlen(sfConfig::get('app_smtp_encryption'))>0)
      {
        $transport->setEncryption(sfConfig::get('app_smtp_encryption'));        
      }   
    }
    else
    {
      $transport = Swift_MailTransport::newInstance();
    }

    //Create the Mailer using your created Transport
    $mailer = Swift_Mailer::newInstance($transport);      

    //Send the message
    if(sfConfig::get('app_use_email_notification'))
    {
      foreach($to as $toEmail=>$toName)
      {              
        
        //Create a message
        $message = Swift_Message::newInstance($subject)
          ->setFrom($from)
          ->setTo(array($toEmail=>$toName))
          ->addPart($body, 'text/html')
          ->setBody(strip_tags(str_replace(array('<br>','<p>','</p>','<h3>','</h3>','<tr>'),"\n",str_replace(array("\r\n", "\n", "\r"),"",$body))))
          ;
                
        try
        {        
          @$mailer->send($message);
        } 
        catch (Exception $e)
        {
          if($user)
          {
            $user->setFlash('userNotices', 'Error sending email: ' . $e->getMessage());
          }
          else
          {
            die($e->getMessage());
          }
                                                         
        }      
      }
    }
        
  }
  
  public static function getRandomPassword($passwordLength = 7)
  {
    $passwordChars = "abcdefghijkmnopqrstuvwxyz023456789ABCDEFGHIJKMNOPQRSTUVWXYZ";

    $password = '' ;
    
    for($i=0; $i<$passwordLength; $i++)
    {
        $password .= $passwordChars[rand(0,58)];
    }
    
    return $password;
  }
  
  public static function isAllowDelete($userId)
  {
    $counts = array();
    
    $c = new Criteria();
    $c->add('','(' . ProjectsPeer::CREATED_BY . '=' . $userId . " or FIND_IN_SET(" . $userId . "," . ProjectsPeer::TEAM . "))", Criteria::CUSTOM);
    $counts['countProjects'] = ProjectsPeer::doCount($c);
    
    $c = new Criteria(); 
    $c->add(ProjectsCommentsPeer::CREATED_BY, $userId );
    $counts['countProjectsComments'] = ProjectsCommentsPeer::doCount($c);
    
    $c = new Criteria();
    $c->add('','(' . TasksPeer::ASSIGNED_TO . '=' . $userId . " or " . TasksPeer::CREATED_BY . "="  . $userId . ")", Criteria::CUSTOM);    
    $counts['countTasks'] = TasksPeer::doCount($c);
    
    $c = new Criteria(); 
    $c->add(TasksCommentsPeer::CREATED_BY, $userId );
    $counts['countTasksComments'] = TasksCommentsPeer::doCount($c);
    
    $c = new Criteria();
    $c->add(TicketsPeer::USERS_ID, $userId );    
    $counts['countTickets'] = TicketsPeer::doCount($c);
    
    $c = new Criteria(); 
    $c->add(TicketsCommentsPeer::USERS_ID, $userId );
    $counts['countTicketsComments'] = TicketsCommentsPeer::doCount($c);
    
    foreach($counts as $v)
    {
      if($v>0) return false;
    }
    
    return true;
  }
  
  public static function countProjectsByUserId($id)
  {
    $c = new Criteria();
    $c->add('',"FIND_IN_SET(" . $id . "," . ProjectsPeer::TEAM . ")", Criteria::CUSTOM);
    
    return ProjectsPeer::doCount($c);
  }
}
